#========================================================================================
# package      DE_EPAGES::OneSaas::t::UserIntegration
# state        private
#========================================================================================
package DE_EPAGES::OneSaas::t::UserIntegration;
use base DE_EPAGES::Shop::API::Test;

use strict;

use DE_EPAGES::Object::API::Factory qw ( LoadObjectByPath LoadRootObject );
use DE_EPAGES::Permission::API::Permission qw( IsActionAllowed );
use DE_EPAGES::OneSaas::API::User qw ( CreateOneSaasUser GetOneSaasAuthToken );
use Test::More tests => 2;

sub init {
    my $self = shift;

    $self->SUPER::init();

    my $App = $self->app;
    $self->{OldPasword} = $App->get('Password');
    $App->set({ 'Password' => 'testPasswordTemp' });

    my $System = $self->system;
    $self->{OldSecret} = $System->get('OneSaasSecret');
    $System->set({ 'OneSaasSecret' => 'testSecret' });
    return;
}

sub cleanup {
    my $self = shift;

    $self->SUPER::cleanup();

    $self->app->set({ 'Password' => $self->{OldPassword} }) if exists $self->{OldPassword};
    $self->system->set({ 'OneSaasSecret' => $self->{OldSecret} }) if exists $self->{OldSecret};
    return;
}

sub app {
    return LoadObjectByPath('/ClientApplications/OneSaas');
}

sub system {
    return LoadRootObject();
}

sub test {
    my $self = shift;
    my $Shop = $self->shop;

    # step 1: create user and check permission.
    my $User = CreateOneSaasUser( $Shop, 'testUserPassword' );
    ok( IsActionAllowed( $Shop, $User, LoadObjectByPath('/Classes/Shop/Roles/WebService') ), 'use can do WS' );

    # step 2: create token for user
    my $Token = GetOneSaasAuthToken( $User->pathString, 'testUserPassword', 'http://host/soap/url' );

    ok( $Token, 'token is generated' );
}

__PACKAGE__->runScript;

1;
